# PaymentServiceUpdateFields

A field containing a key-value pair for a required field defined by the service for this payment service.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**key** | **str** | The key of the field to set a value for. | 
**value** | **str** | The value of a field to set. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


